@@ -51,8 +51,8 @@ class TechDocsMetadataPlugin(BasePlugin):
             page.meta = page_meta
 
         # Traverse up the directory tree to locate mkdocs-awesome-page .pages files
-        # and collect titles as page parents
-        titles = []
+        # and collect titles and directory paths as page parents
+        parents = []
         current_dir = file_dir
         docs_dir = os.path.abspath(config.docs_dir)
         while current_dir:
@@ -70,8 +70,12 @@ class TechDocsMetadataPlugin(BasePlugin):
                                 break
                             current_dir = parent_dir
                             continue
-                        title = pages_data.get("title") or os.path.basename(current_dir)
-                        titles.append(title)
+                        relative_path = os.path.relpath(current_dir, docs_dir)
+                        title = pages_data.get("title", "")
+                        if relative_path != "." and not title:
+                            title = os.path.basename(current_dir)
+                        parents.append({"title": title, "url": f"{relative_path}/"})
+
             parent_dir = os.path.dirname(current_dir)
             if parent_dir == current_dir or current_dir == docs_dir:
                 break
@@ -82,9 +86,10 @@ class TechDocsMetadataPlugin(BasePlugin):
                 "title": page.title,
                 "url": page.file.url,
                 "meta": page.meta or {},
-                "parents": titles[::-1],  # Reverse the list to get the correct order
+                "parents": parents[::-1],  # Reverse the list to get the correct order
             }
         )
+
         return markdown
 
     def on_post_build(self, config: MkDocsConfig, **kwargs) -> None:
